# mpservice

Serving with asyncio, multiprocessing, and batching.

One use case is machine learning model serving, although the code is generic and not restricted to any particular use case.

Reference: [Service Batching from Scratch, Again](https://zpz.github.io/blog/batched-service-redesign/). This article describes roughly version 0.7.2.

The package also contains some other related utilities.

To install, do `pip install mpservice`.